@@ -1,5 +1,5 @@
 /*
- *	$Id: lspci.c,v 1.30 1999/10/09 13:26:02 mj Exp $
+ *	$Id: lspci.c,v 1.32 2000/01/13 22:50:13 mj Exp $
  *
  *	Linux PCI Utilities -- List All PCI Devices
  *
@@ -68,7 +68,7 @@ static struct pci_access *pacc;
 
 #ifdef ARCH_SPARC64
 #define IO_FORMAT "%016Lx"
-#elif defined(HAVE_64BIT_ADDRESS)
+#elif defined(HAVE_LONG_ADDRESS)
 #define IO_FORMAT "%04Lx"
 #else
 #define IO_FORMAT "%04lx"
@@ -240,15 +240,20 @@ show_terse(struct device *d)
 			 p->vendor_id, p->device_id, 0, 0));
   if (c = get_conf_byte(d, PCI_REVISION_ID))
     printf(" (rev %02x)", c);
-  if (verbose && (c = get_conf_byte(d, PCI_CLASS_PROG)))
+  if (verbose)
     {
-      char *x = pci_lookup_name(pacc, devbuf, sizeof(devbuf),
-				PCI_LOOKUP_PROGIF,
-				get_conf_word(d, PCI_CLASS_DEVICE), c, 0, 0);
-      printf(" (prog-if %02x", c);
-      if (x)
-	printf(" [%s]", x);
-      putchar(')');
+      char *x;
+      c = get_conf_byte(d, PCI_CLASS_PROG);
+      x = pci_lookup_name(pacc, devbuf, sizeof(devbuf),
+			  PCI_LOOKUP_PROGIF,
+			  get_conf_word(d, PCI_CLASS_DEVICE), c, 0, 0);
+      if (c || x)
+	{
+	  printf(" (prog-if %02x", c);
+	  if (x)
+	    printf(" [%s]", x);
+	  putchar(')');
+	}
     }
   putchar('\n');
 }
